.. EclipsingBinaries documentation master file, created by
   sphinx-quickstart on Sun May 14 20:47:46 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

=================
EclipsingBinaries
=================

.. Important::
   This document page is still a work in progress and there may be things missing so please bare with me as the pages get created and documented.
   
Getting Started
---------------

.. toctree::
   :maxdepth: 1

   installation
   contributing
   changelog
   license

Using `EclipsingBinaries`
-------------------------

.. toctree::
   :maxdepth: 2
   
   pipeline
   EB
   toolbox
